camelot.camelot.model.i18n.Translation

Package camelot :: Package camelot :: Package model :: Module i18n :: Class Translation |
[hide private]
[frames] | no frames]

# Class Translation

source code

Nested Classes | [hide private]
| Admin

Class Methods | [hide private]
translate(cls, source, language) Translate source to language, return None if no translation is found | source code
translate_or_register(cls, source, language) Translate source to language, if no translation is found, register the source as to be translated and return the source | source code

Class Variables | [hide private]
| language = `Field(Unicode(20), index= True)`
| source = `Field(Unicode(500), index= True)`
| value = `Field(Unicode(500))`
| cid = `Field(INT(), default= 0, index= True)`
| uid = `Field(INT(), default= 0, index= True)`
| _cache = `dict()`